@@ -1,5 +1,5 @@
-aecheck <- function(a, b, field) {
-  e <- all.equal(a, b)
+aecheck <- function(a, b, field, ...) {
+  e <- all.equal(a, b, ...)
   if (!isTRUE(e)) {
     paste0("Field ", field, " mismatch: ", e)
   } else {
